FieldPosition

Struct FieldPosition 

pub struct FieldPosition {
    pub group: usize,
    pub field: usize,
    pub first_field: usize,
    pub last_field: usize,
    pub group_count: usize,
    pub first_group: usize,
    pub last_group: usize,
}
Positional information about a field within a form.

Fields

group: usize

Current group index.

field: usize

Current field index within group.

first_field: usize

First non-skipped field index.

last_field: usize

Last non-skipped field index.

group_count: usize

Total number of groups.

first_group: usize

First non-hidden group index.

last_group: usize

Last non-hidden group index.

Implementations

Source

impl FieldPosition

pub fn is_first(&self) -> bool

Returns whether this field is the first in the form.

pub fn is_last(&self) -> bool

Returns whether this field is the last in the form.