pub struct LayoutGrid { /* private fields */ }Expand description
Grid layout - arranges groups in a fixed grid pattern.
Groups are arranged in a grid with the specified number of rows and columns. If there are more groups than cells, extra groups are not displayed.
Implementations