pub struct Select<T: Clone + PartialEq + Send + Sync + 'static> { /* private fields */ }Expand description
A select field for choosing one option from a list.
Implementations
Sourceimpl<T: Clone + PartialEq + Send + Sync + Default + 'static> Select<T>
impl<T: Clone + PartialEq + Send + Sync + Default + 'static> Select<T>
Sourcepub fn options(self, options: Vec<SelectOption<T>>) -> Self
pub fn options(self, options: Vec<SelectOption<T>>) -> Self
Sets the options.
Sourcepub fn description(self, description: impl Into<String>) -> Self
pub fn description(self, description: impl Into<String>) -> Self
Sets the description.
Sourcepub fn validate(self, validate: fn(&T) -> Option<String>) -> Self
pub fn validate(self, validate: fn(&T) -> Option<String>) -> Self
Sets the validation function.
Sourcepub fn height_options(self, height: usize) -> Self
pub fn height_options(self, height: usize) -> Self
Sets the visible height (number of options shown).
Sourcepub fn filterable(self, enabled: bool) -> Self
pub fn filterable(self, enabled: bool) -> Self
Enables or disables type-to-filter support.
When filtering is enabled, typing characters will filter the visible options. Navigation keys (j/k/g/G) still work for movement. Press Escape to clear the filter, Backspace to delete the last character.
Sourcepub fn get_selected_value(&self) -> Option<&T>
pub fn get_selected_value(&self) -> Option<&T>
Gets the currently selected value.